@@ -25,6 +25,7 @@ from .concatenate import concatenate
 from .count_nonzero import count_nonzero
 from .cumsum import cumsum
 from .diag import diag
+from .diff import diff
 from .diagonal import diagonal
 from .true_divide import true_divide, true_divide as divide
 from .divmod import divmod
@@ -40,9 +41,11 @@ from .hstack import hstack
 from .hsplit import hsplit
 from .less import less
 from .less_equal import less_equal
+from .load import load
 from .inner import inner
 from .isclose import isclose
 from .isfinite import isfinite
+from .loadtxt import loadtxt
 from .logical_and import logical_and
 from .logical_or import logical_or
 from .matmul import matmul
@@ -62,7 +65,12 @@ from .prod import prod
 from .remainder import remainder as mod, remainder
 from .repeat import repeat
 from .reshape import reshape
+from .result_type import result_type
 from .rint import rint
+from .save import save
+from .savetxt import savetxt
+from .savez import savez
+from .savez_compressed import savez_compressed
 from .split import split
 from .square import square
 from .stack import stack
